from setuptools import setup

setup(name='yitest',
      version='0.3',
      description='The funniest joke in the world',
      url='https://github.com/dymodi/machine_learning',
      author='yi',
      author_email='dymodi@gmail.com',
      license='MIT',
      packages=['yitest'],
      zip_safe=False)